Index: include/v8-profiler.h |
diff --git a/include/v8-profiler.h b/include/v8-profiler.h |
index bcca65edbcab607196694d06e15b2464828f5253..61b13b81f632cc5bba1b092552b0a9bab47bc657 100644 |
--- a/include/v8-profiler.h |
+++ b/include/v8-profiler.h |
@@ -255,7 +255,11 @@ class V8EXPORT HeapGraphNode { |
kClosure = 5, // Function closure. |
kRegExp = 6, // RegExp. |
kHeapNumber = 7, // Number stored in the heap. |
- kNative = 8 // Native object (not from V8 heap). |
+ kNative = 8, // Native object (not from V8 heap). |
+ kArtificial = 9 // Artificial object, usualy used for grouping |
mnaganov (inactive)
2012/02/06 12:23:00
I'd rename this to kVirtual, as virtual is somethi
mnaganov (inactive)
2012/02/06 12:23:00
Also, let's convert existing virtual nodes -- the
|
+ // snapshot items together for reducing |
+ // postprocessing steps. |
+ // example - group of detached DOM trees. |
}; |
/** Returns node type (see HeapGraphNode::Type). */ |
@@ -501,6 +505,9 @@ class V8EXPORT RetainedObjectInfo { // NOLINT |
/** Returns embedder's object size in bytes. */ |
virtual intptr_t GetSizeInBytes() { return -1; } |
+ /** Returns embedder's object type. */ |
+ virtual HeapGraphNode::Type GetType() const { return HeapGraphNode::kNative; } |
mnaganov (inactive)
2012/02/06 12:23:00
I'm strongly against adding this method. It's only
|
+ |
protected: |
RetainedObjectInfo() {} |
virtual ~RetainedObjectInfo() {} |